==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property gA
 * @property public
 */
public data class SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs(
    public val gA: Output<String>? = null,
    public val `public`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs =
        com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs.builder()
            .gA(gA?.applyValue({ args0 -> args0 }))
            .public_(`public`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs].
 */
@PulumiTagMarker
public class SecurityAssessmentMetadataPropertiesResponsePublishDatesArgsBuilder internal
constructor() {
    private var gA: Output<String>? = null

    private var `public`: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ufuhxunkdhnspqah")
    public suspend fun gA(`value`: Output<String>) {
        this.gA = value
    }

    /**
     * @param value
     */
    @JvmName("trkwjqqhpbeukgky")
    public suspend fun `public`(`value`: Output<String>) {
        this.`public` = value
    }

    /**
     * @param value
     */
    @JvmName("lbcbdabrxggfinxa")
    public suspend fun gA(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gA = mapped
    }

    /**
     * @param value
     */
    @JvmName("ifwonjufrwwejido")
    public suspend fun `public`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`public` = mapped
    }

    internal fun build(): SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs =
        SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs(
            gA = gA,
            `public` = `public` ?: throw PulumiNullFieldException("public"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property gA
 * @property public
 */
public data class SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs(
    public val gA: Output<String>? = null,
    public val `public`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs =
        com.pulumi.azurenative.security.inputs.SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs.builder()
            .gA(gA?.applyValue({ args0 -> args0 }))
            .public_(`public`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs].
 */
@PulumiTagMarker
public class SecurityAssessmentMetadataPropertiesResponsePublishDatesArgsBuilder internal
constructor() {
    private var gA: Output<String>? = null

    private var `public`: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("oqbckwiodnoxlwkr")
    public suspend fun gA(`value`: Output<String>) {
        this.gA = value
    }

    /**
     * @param value
     */
    @JvmName("jistngpkdkncbrrk")
    public suspend fun `public`(`value`: Output<String>) {
        this.`public` = value
    }

    /**
     * @param value
     */
    @JvmName("ltleljacemjuahbr")
    public suspend fun gA(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gA = mapped
    }

    /**
     * @param value
     */
    @JvmName("orjnmfclixljxdxc")
    public suspend fun `public`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`public` = mapped
    }

    internal fun build(): SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs =
        SecurityAssessmentMetadataPropertiesResponsePublishDatesArgs(
            gA = gA,
            `public` = `public` ?: throw PulumiNullFieldException("public"),
        )
}
